"""
A dictionary with attribute - metadata pairings
Three IVOA metadata elements in the dictionary are 
ucd, unit, datatype in that order.
For further info check:
http://www.ivoa.net/documents/VOEvent/
"""

CatalogsMetadataMap = {'diaSourceId': ('meta.id;meta.main', '', 'uint64'), 
                       'ccdVisitId': ('meta.id;instr.param', '', 'uint64'), 
                       'diaObjectId': ('meta.id.assoc', '', 'uint64'), 
                       'ssObjectId': ('meta.id.assoc', '', 'uint64'), 
                       'parentSourceId': ('meta.id.parent', '', 'uint64'), 
                       'midPointTai': ('time.epoch', 'time', 'double'), 
                       'filterName': ('instr.filter', '', 'bit[8]'), 
                       'ra': ('pos.eq.ra;pos.eq.dec;meta.main', 'degrees', 'double'), 
                       'dec': ('pos.eq.ra;pos.eq.dec;meta.main', 'degrees', 'double'), 
                       'raVar': ('stat.covariance;pos.eq', 'various', 'float'), 
                       'decVar': ('stat.covariance;pos.eq', 'various', 'float'), 
                       'ra_dec_Cov': ('stat.covariance;pos.eq', 'various', 'float'), 
                       'x': ('instr.pixel', 'pixels', 'float'), 
                       'y': ('instr.pixel', 'pixels', 'float'), 
                       'xVar': ('stat.covariance', 'various', 'float'), 
                       'yVar': ('stat.covariance', 'various', 'float'), 
                       'x_y_Cov': ('stat.covariance', 'various', 'float'), 
                       'apMeanSb01': ('phot.flux;arith.diff;phot.calib', 'nmgy', 'float'), 
                       'apMeanSb02': ('phot.flux;arith.diff;phot.calib', 'nmgy', 'float'), 
                       'apMeanSb03': ('phot.flux;arith.diff;phot.calib', 'nmgy', 'float'), 
                       'apMeanSb04': ('phot.flux;arith.diff;phot.calib', 'nmgy', 'float'), 
                       'apMeanSb05': ('phot.flux;arith.diff;phot.calib', 'nmgy', 'float'), 
                       'apMeanSb06': ('phot.flux;arith.diff;phot.calib', 'nmgy', 'float'), 
                       'apMeanSb07': ('phot.flux;arith.diff;phot.calib', 'nmgy', 'float'), 
                       'apMeanSb08': ('phot.flux;arith.diff;phot.calib', 'nmgy', 'float'), 
                       'apMeanSb09': ('phot.flux;arith.diff;phot.calib', 'nmgy', 'float'), 
                       'apMeanSb10': ('phot.flux;arith.diff;phot.calib', 'nmgy', 'float'), 
                       'apMeanSb01Sigma': ('stat.error;phot.flux', 'nmgy', 'float'), 
                       'apMeanSb02Sigma': ('stat.error;phot.flux', 'nmgy', 'float'), 
                       'apMeanSb03Sigma': ('stat.error;phot.flux', 'nmgy', 'float'), 
                       'apMeanSb04Sigma': ('stat.error;phot.flux', 'nmgy', 'float'), 
                       'apMeanSb05Sigma': ('stat.error;phot.flux', 'nmgy', 'float'), 
                       'apMeanSb06Sigma': ('stat.error;phot.flux', 'nmgy', 'float'), 
                       'apMeanSb07Sigma': ('stat.error;phot.flux', 'nmgy', 'float'), 
                       'apMeanSb08Sigma': ('stat.error;phot.flux', 'nmgy', 'float'), 
                       'apMeanSb09Sigma': ('stat.error;phot.flux', 'nmgy', 'float'), 
                       'apMeanSb10Sigma': ('stat.error;phot.flux', 'nmgy', 'float'), 
                       'snr': ('stat.snr', 'nmgy', 'float'), 
                       'psFlux': ('phot.flux;arith.diff', 'degrees', 'float'), 
                       'psRa': ('pos.eq.ra;pos.eq.dec', 'various', 'double'), 
                       'psDec': ('pos.eq.ra;pos.eq.dec', 'various', 'double'), 
                       'psFluxVar': ('stat.covariance;pos.eq', '', 'float'), 
                       'psRaVar': ('stat.covariance;pos.eq', '', 'float'), 
                       'psDecVar': ('stat.covariance;pos.eq', '', 'float'), 
                       'psFlux_psRa_Cov': ('stat.covariance;pos.eq', '', 'float'), 
                       'psFlux_psDec_Cov': ('stat.covariance;pos.eq', '', 'float'), 
                       'psRa_psDec_Cov': ('stat.covariance;pos.eq', '', 'float'), 
                       'psLnL': ('stat.likelihood;', '', 'float'), 
                       'psChi2': ('stat.fit.chi2', '', 'float'), 
                       'psN': ('stat.value', 'nmgy', 'int'), 
                       'trailFlux': ('phot.flux;arith.diff;phot.calib', 'degrees', 'float'), 
                       'trailRa': ('pos.?', 'arcsec', 'double'), 
                       'trailDec': ('pos.?', 'arcsec', 'double'), 
                       'trailLength': ('stat.likelihood;stat.max', 'degrees', 'float'), 
                       'trailAngle': ('stat.likelihood;stat.max', 'various', 'float'), 
                       'trailFluxVar': ('stat.covariance', '', 'float'), 
                       'trailRaVar': ('stat.covariance', '', 'float'), 
                       'trailDecVar': ('stat.covariance', '', 'float'), 
                       'trailLengthVar': ('stat.covariance', '', 'float'), 
                       'trailAngleVar': ('stat.covariance', '', 'float'), 
                       'trailFlux_trailRa_Cov': ('stat.covariance', '', 'float'), 
                       'trailFlux_trailDec_Cov': ('stat.covariance', '', 'float'), 
                       'trailFlux_trailLength_Cov': ('stat.covariance', '', 'float'), 
                       'trailFlux_trailAngle_Cov': ('stat.covariance', '', 'float'), 
                       'trailRa_trailDec_Cov': ('stat.covariance', '', 'float'), 
                       'trailRa_trailLength_Cov': ('stat.covariance', '', 'float'), 
                       'trailRa_trailAngle_Cov': ('stat.covariance', '', 'float'), 
                       'trailDec_trailLength_Cov': ('stat.covariance', '', 'float'), 
                       'trailRa_trailAngle_Cov': ('stat.covariance', '', 'float'), 
                       'trailLength_trailAngle_Cov': ('stat.covariance', '', 'float'), 
                       'trailLnL': ('stat.likelihood', '', 'float'), 
                       'trailChi2': ('stat.fit.chi2', '', 'float'), 
                       'trailN': ('stat.value', 'nmgy', 'int'), 
                       'dipMeanFlux': ('stat.likelihood;stat.max', 'nmgy', 'float'), 
                       'dipFluxDiff': ('stat.likelihood;stat.max', 'degrees', 'float'), 
                       'dipRa': ('pos.?', 'arcsec', 'double'), 
                       'dipDec': ('pos.?', 'arcsec', 'double'), 
                       'dipLength': ('stat.likelihood;stat.max', 'degrees', 'float'), 
                       'dipAngle': ('stat.likelihood;stat.max', 'various', 'float'), 
                       'dipMeanFluxVar': ('stat.covariance', '', 'float'), 
                       'dipFluxDiffVar': ('stat.covariance', '', 'float'), 
                       'dipRaVar': ('stat.covariance', '', 'float'), 
                       'dipDecVar': ('stat.covariance', '', 'float'), 
                       'dipLengthVar': ('stat.covariance', '', 'float'), 
                       'dipAngleVar': ('stat.covariance', '', 'float'), 
                       'dipMeanFlux_dipFluxDiff_Cov': ('stat.covariance', '', 'float'), 
                       'dipMeanFlux_dipRa_Cov': ('stat.covariance', '', 'float'), 
                       'dipMeanFlux_dipDec_Cov': ('stat.covariance', '', 'float'), 
                       'dipMeanFlux_dipLength_Cov': ('stat.covariance', '', 'float'), 
                       'dipMeanFlux_dipAngle_Cov': ('stat.covariance', '', 'float'), 
                       'dipFluxDiff_dipRa_Cov': ('stat.covariance', '', 'float'), 
                       'dipFluxDiff_dipDec_Cov': ('stat.covariance', '', 'float'), 
                       'dipFluxDiff_dipLength_Cov': ('stat.covariance', '', 'float'), 
                       'dipFluxDiff_dipAngle_Cov': ('stat.covariance', '', 'float'), 
                       'dipRa_dipDec_Cov': ('stat.covariance', '', 'float'), 
                       'dipRa_dipLength_Cov': ('stat.covariance', '', 'float'), 
                       'dipRa_dipAngle_Cov': ('stat.covariance', '', 'float'), 
                       'dipDec_dipLength_Cov': ('stat.covariance', '', 'float'), 
                       'dipDec_dipAngle_Cov': ('stat.covariance', '', 'float'), 
                       'dipLength_dipAngle_Cov': ('stat.covariance', '', 'float'), 
                       'dipLnL': ('stat.likelihood', '', 'float'), 
                       'dipChi2': ('stat.fit.chi2', '', 'float'), 
                       'dipN': ('stat.value', 'nmgy', 'int'), 
                       'totFlux': ('phot.flux;arith.diff;phot.calib', 'nmgy', 'float'), 
                       'totFluxErr': ('stat.error;phot.flux', 'nmgy', 'float'), 
                       'diffFlux': ('phot.flux;arith.diff;phot.calib', 'nmgy', 'float'), 
                       'diffFluxErr': ('stat.error;phot.flux', 'nmgy/asec^2', 'float'), 
                       'fpBkgd': ('pos.cmb', 'nmgy/asec^2', 'float'), 
                       'fpBkgdErr': ('stat.error;pos.cmb', 'nmgy/asec^2', 'float'), 
                       'Ixx': ('', 'nmgy/asec^2', 'float'), 
                       'Iyy': ('', 'nmgy/asec^2', 'float'), 
                       'Ixy': ('', 'nmgy^2 asec^4', 'float'), 
                       'IxxVar': ('stat.covariance', 'nmgy/asec^2', 'float'), 
                       'IyyVar': ('stat.covariance', 'nmgy/asec^2', 'float'), 
                       'IxyVar': ('stat.covariance', 'nmgy/asec^2', 'float'), 
                       'Ixx_Iyy_Cov': ('stat.covariance', 'nmgy/asec^2', 'float'), 
                       'Ixx_Ixy_Cov': ('stat.covariance', 'nmgy/asec^2', 'float'), 
                       'Iyy_Ixy_Cov': ('stat.covariance', 'nmgy/asec^2', 'float'), 
                       'IxxPSF': ('instr.det.psf', 'nmgy/asec^2', 'float'), 
                       'IyyPSF': ('instr.det.psf', 'nmgy/asec^2', 'float'), 
                       'IxyPSF': ('instr.det.psf', '', 'float'), 
                       'extendedness': ('', '', 'float'), 
                       'spuriousness': ('', 'bit', 'float'), 
                       'flags': ('meta.code', '', 'bit[64]'),
                       # vanilla attrs from catsim
                       'id': ('meta.id', '', 'uint64'), 
                       'raJ2000': ('pos.eq.ra', 'degrees', 'double'), 
                       'decJ2000': ('pos.eq.dec', 'degrees', 'double'), 
                       'lsst_u': ('phot.mag', '', 'double), 
                       'lsst_g': ('phot.mag', '', 'double), 
                       'lsst_r': ('phot.mag', '', 'double), 
                       'lsst_i': ('phot.mag', '', 'double), 
                       'lsst_z': ('phot.mag', '', 'double), 
                       'lsst_y': ('phot.mag', '', 'double), 
                       'delta_lsst_u': ('phot.mag', '', 'double), 
                       'delta_lsst_g': ('phot.mag', '', 'double), 
                       'delta_lsst_r': ('phot.mag', '', 'double), 
                       'delta_lsst_i': ('phot.mag', '', 'double), 
                       'delta_lsst_z': ('phot.mag', '', 'double), 
                       'delta_lsst_y': ('phot.mag', '', 'double), 
                       'gal_l': ('', '', double), 
                       'gal_b': ('', '', double), 
                       'varParamStr': ('src.var', '', 'string')
                       }
